
XYCurves
========


.. automodule:: opendssdirect.XYCurves
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.XYCurves.Count

    Get number of XYCurves in active circuit.

.. function:: opendssdirect.XYCurves.First

    Set first XYCurves object active; returns 0 if none.

.. function:: opendssdirect.XYCurves.Name

    Get the name of the active XYCurve Object.Set the name of the active XYCurve Object.

.. function:: opendssdirect.XYCurves.Next

    Set next XYCurves object active; returns 0 if none.

.. function:: opendssdirect.XYCurves.Npts

    Get the number of points in X-Y curve.Set the number of points in X-Y curve.

.. function:: opendssdirect.XYCurves.X

    Get the interpolated value after setting Y.Set the X value.

.. function:: opendssdirect.XYCurves.XArray

    Get the X values as a vector of doubles. Set Npts to max number expected if setting.

.. function:: opendssdirect.XYCurves.XScale

    Get the factor to scale X values from original curve.Set the factor to scale X values from original curve.

.. function:: opendssdirect.XYCurves.XShift

    Get the amount to shift X value from original curve.Set the amount to shift X value from original curve.

.. function:: opendssdirect.XYCurves.Y

    Get the interpolated value after setting X.Set the Y value.

.. function:: opendssdirect.XYCurves.YArray

    Get the Y values as a vector of doubles. Set Npts to max number expected if setting.

.. function:: opendssdirect.XYCurves.YScale

    Get the factor to scale Y values from original curve.Set the factor to scale Y values from original curve.

.. function:: opendssdirect.XYCurves.YShift

    Get the amount to shift Y value from original curve.Set the amount to shift Y value from original curve.

